@@ -252,7 +252,6 @@ build_launch_environment (GdmLaunchEnvironment *launch_environment,
         g_free (system_data_dirs);
 
         g_hash_table_insert (hash, g_strdup ("XAUTHORITY"), g_strdup (launch_environment->priv->x11_authority_file));
-        g_hash_table_insert (hash, g_strdup ("DISPLAY"), g_strdup (launch_environment->priv->x11_display_name));
 
         g_hash_table_insert (hash, g_strdup ("LOGNAME"), g_strdup (launch_environment->priv->user_name));
         g_hash_table_insert (hash, g_strdup ("USER"), g_strdup (launch_environment->priv->user_name));
@@ -289,9 +288,6 @@ build_launch_environment (GdmLaunchEnvironment *launch_environment,
         g_hash_table_insert (hash, g_strdup ("PATH"), g_strdup (g_getenv ("PATH")));
 
         g_hash_table_insert (hash, g_strdup ("RUNNING_UNDER_GDM"), g_strdup ("true"));
-        g_hash_table_insert (hash, g_strdup ("GVFS_DISABLE_FUSE"), g_strdup ("1"));
-        g_hash_table_insert (hash, g_strdup ("GIO_USE_VFS"), g_strdup ("local"));
-        g_hash_table_insert (hash, g_strdup ("GVFS_REMOTE_VOLUME_MONITOR_IGNORE"), g_strdup ("1"));
         g_hash_table_insert (hash, g_strdup ("DCONF_PROFILE"), g_strdup ("gdm"));
 
         if (launch_environment->priv->dbus_session_bus_address) {
@@ -474,34 +470,41 @@ gdm_launch_environment_start (GdmLaunchEnvironment *launch_environment)
                                                              launch_environment->priv->x11_display_is_local,
                                                              NULL);
 
-        g_signal_connect (launch_environment->priv->session,
-                          "conversation-started",
-                          G_CALLBACK (on_conversation_started),
-                          launch_environment);
-        g_signal_connect (launch_environment->priv->session,
-                          "conversation-stopped",
-                          G_CALLBACK (on_conversation_stopped),
-                          launch_environment);
-        g_signal_connect (launch_environment->priv->session,
-                          "setup-complete",
-                          G_CALLBACK (on_session_setup_complete),
-                          launch_environment);
-        g_signal_connect (launch_environment->priv->session,
-                          "session-opened",
-                          G_CALLBACK (on_session_opened),
-                          launch_environment);
-        g_signal_connect (launch_environment->priv->session,
-                          "session-started",
-                          G_CALLBACK (on_session_started),
-                          launch_environment);
-        g_signal_connect (launch_environment->priv->session,
-                          "session-exited",
-                          G_CALLBACK (on_session_exited),
-                          launch_environment);
-        g_signal_connect (launch_environment->priv->session,
-                          "session-died",
-                          G_CALLBACK (on_session_died),
-                          launch_environment);
+        g_signal_connect_object (launch_environment->priv->session,
+                                 "conversation-started",
+                                 G_CALLBACK (on_conversation_started),
+                                 launch_environment,
+                                 0);
+        g_signal_connect_object (launch_environment->priv->session,
+                                 "conversation-stopped",
+                                 G_CALLBACK (on_conversation_stopped),
+                                 launch_environment,
+                                 0);
+        g_signal_connect_object (launch_environment->priv->session,
+                                 "setup-complete",
+                                 G_CALLBACK (on_session_setup_complete),
+                                 launch_environment,
+                                 0);
+        g_signal_connect_object (launch_environment->priv->session,
+                                 "session-opened",
+                                 G_CALLBACK (on_session_opened),
+                                 launch_environment,
+                                 0);
+        g_signal_connect_object (launch_environment->priv->session,
+                                 "session-started",
+                                 G_CALLBACK (on_session_started),
+                                 launch_environment,
+                                 0);
+        g_signal_connect_object (launch_environment->priv->session,
+                                 "session-exited",
+                                 G_CALLBACK (on_session_exited),
+                                 launch_environment,
+                                 0);
+        g_signal_connect_object (launch_environment->priv->session,
+                                 "session-died",
+                                 G_CALLBACK (on_session_died),
+                                 launch_environment,
+                                 0);
 
         gdm_session_start_conversation (launch_environment->priv->session, "gdm-launch-environment");
 
